Coverage for hookee/plugins/request_query_params.py: 100.00%

# Coverage for hookee/plugins/request_query_params.py : 100.00%

## 14 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from hookee.pluginmanager import REQUEST_PLUGIN

2 from hookee.util import PrintUtil

3

4 __author__ = "Alex Laird"

5 __copyright__ = "Copyright 2020, Alex Laird"

6 __version__ = "1.2.2"

7

8 plugin_type = REQUEST_PLUGIN

9 description = "Print the `request`'s query parameters, if defined."

10

11 print_util = None # type: PrintUtil

12

13

14 def setup(hookee_manager):

15 global print_util

16

17 print_util = hookee_manager.print_util

18

19

20 def run(request):

21 if request.args:

22 print_util.print_dict("Query Params", dict(request.args), color=print_util.request_color)

23

24 return request